@@ -206,10 +206,16 @@ class WorkflowEnabledMeta(base.WorkflowEnabledMeta, models.base.ModelBase):
     def _add_workflow(mcs, field_name, state_field, attrs):
         """Attach the workflow to a set of attributes.
 
-        This sets the django-specific StateField.
-        """
-        attrs[field_name] = state_field
+        Constructs the ImplementationWrapper for transitions, and adds them to
+        the attributes dict.
 
+        Args:
+            field_name (str): name of the attribute where the StateField lives
+            state_field (StateField): StateField describing that attribute
+            attrs (dict): dictionary of attributes for the class being created
+        """
+        # No need to override the 'field_name' from attrs: it already contains
+        # a valid value, and that would clash with django model inheritance.
         implems = base.ImplementationList(field_name, state_field.workflow)
         implems.transform(attrs)
 
@@ -242,15 +248,20 @@ class BaseTransitionLog(models.Model):
                                      verbose_name=_(u"Content type"),
                                      related_name="workflow_object",
                                      blank=True, null=True)
-    content_id = models.PositiveIntegerField(_(u"Content id"), blank=True, null=True)
+    content_id = models.PositiveIntegerField(_(u"Content id"),
+        blank=True, null=True, db_index=True)
     modified_object = generic.GenericForeignKey(
             ct_field="content_type",
             fk_field="content_id")
 
-    transition = models.CharField(_(u"transition"), max_length=255)
-    from_state = models.CharField(_(u"from state"), max_length=255)
-    to_state = models.CharField(_(u"to state"), max_length=255)
-    timestamp = models.DateTimeField(_(u"performed at"), default=datetime.datetime.now)
+    transition = models.CharField(_(u"transition"), max_length=255,
+        db_index=True)
+    from_state = models.CharField(_(u"from state"), max_length=255,
+        db_index=True)
+    to_state = models.CharField(_(u"to state"), max_length=255,
+        db_index=True)
+    timestamp = models.DateTimeField(_(u"performed at"),
+        default=datetime.datetime.now, db_index=True)
 
     class Meta:
         ordering = ('-timestamp', 'transition')
